
# S3 dataset

## Information
The S3 dataset contains the behavior (sensors, statistics of applications, and voice) of 21 volunteers interacting with their smartphones for more than 60 days. The type of users is diverse, males and females in the age range from 18 until 70 have been considered in the dataset generation. The wide range of age is a key aspect, due to the impact of age in terms of smartphone usage. To generate the dataset the volunteers installed a prototype of the smartphone application in [1] on their Android mobile phones.

All attributes of the different kinds of data are writed in a vector. The dataset contains the fellow vectors: 

### Sensors: 
This type of vector contains data belonging to smartphone sensors (accelerometer and gyroscope) that has been acquired in a given windows of time. Each vector is obtained every 20 seconds, and the monitored features are:

- Average of accelerometer and gyroscope values.
- Maximum and minimum of accelerometer and gyroscope values.
- Variance of accelerometer and gyroscope values.
- Peak-to-peak (max-min) of X, Y, Z coordinates.
- Magnitude for gyroscope and accelerometer [2].

### Statistics: 
These vectors contain data about the different applications used by the user recently. Each vector of statistics is calculated every 60 seconds and contains [3]: 

- Foreground application counters (number of different and total apps) for the last minute and the last day.
- Most common app ID and the number of usages in the last minute and the last day. 
- ID of the currently active app. 
- ID of the last active app prior to the current one.
- ID of the application most frequently utilized prior to the current application. 
- Bytes transmitted and received through the network interfaces. 

### Voice: 
This kind of vector is generated when the microphone is active in a call o voice note. The speaker vector is an embedding, extracted from the audio, and it contains information about the user's identity. This vector, is usually named "x-vector" in the Speaker Recognition field, and it is calculated following the steps detailed in "egs/sitw/v2" [4] for the Kaldi library [5], with the models available on [6] for the extraction of the embedding. 

## Summary
A summary of the details of the collected database.

| Characteristic | Number |
|----------------|----------|
| Users | 21 |
| Sensors vectors | 417.128 |
| Statistics app's usage vectors | 151.034 |
| Speaker vectors: | 2.720 |
| -- Call recordings | 629 |
| -- Voice messages | 2.091 |

## Data Organization
The organization of the data set is as follows:
```
S3Dataset
+-- Readme.md
+-- data
|   +-- authvoicedata_000001
|   +-- authvoicedata_000002
            ...
|   +-- authvoicedata_022440
+-- info
|   +-- S3dataset.txt
+-- protocols
|   +-- Xdays-vs-all.tst
|   +-- Xdays-vs-all.trn

```

### Data Files
The data vectors for each user are grouped into files named "authvoicedata_ *". To start writing a new file, it takes more than 5 minutes without user activity. The structure of the file is as follows:
```
{timestamp},{vector}
```
{timestamp}: timestamp of when the vector was generated.
{vector}: vector of sensors, statistics or voice described above. Vector is in CSV format. The sensors and statistics vector contain at the end two new attributes added which are the day and the hour at which it is obtained.


### Info Files
The 'S3dataset.txt' contain information about the data files. The structure of the file is as follows:

```
{file} {user} {tmsIni} {tmsEnd} {dur} {type}
```
{file}: data file that contains the vectors to test agains the model.
{user}: name of the user
{tmsIni}: first timestamp in miliseconds.
{tmsEnd}: last timestamp in miliseconds.
{dur}: duration of sessions in seconds
{type}: the possible types is a combination of "st", if contains data from sensors and statistics, "cr", for call recordings and "vn" for voice notes; separated by "_". For example, "st_vn_cr".



### Protocols Files
#### - Train files "X"days-vs-all.trn
This file contains the information needed to generate the user profiles using "X" days to train.
This file contains one line for each of the users. In this line, the information necessary to build the user models is given. Its structure is as follows:
```
{nameModel} {secondsTrain} {tmsIni} {tmsEnd} st_vn{x}_cr{y} {files}
```
{nameModel}: name given to model.
{secondsTrain}: duration in seconds of the data used for training.
{tmsIni}: timestamp for the day to start generating models.
{tmsEnd}: timestamp for the day to end generating models.
st_vn{x}_cr{y}: indicates the amount of data that the model contains. {x} number of voice notes, {cr} number of call recordings
{files}: data files that contains the vectors.

#### - Train files "X"days-vs-all.tst
This file contains the information necessary to perform a test where user profiles are trained using "X" days of data.
This file contains one line for each comparison. In this line the information necessary to verify the identity is given. Its structure is as follows:
```
{nameModel} {file} {label}
```
{nameModel}: name given to model.
{file}: data file that contains the vectors to test agains the model.
{label}: label, "target" if the user from files is the same for the {nameModel}, "nontarget" in other case.

## References
[1] -- To publish -- Espín López, J.M.;Huertas Celdrán, A.;Marín-Blázquez, J.G.; EsquembreMartínez, F.; Martínez Pérez, G. S3:An AI-enabled User ContinuousAuthentication for Smartphonesbased on Sensors, Statistics andSpeaker Information.
[2] Ehatisham-ul Haq, M.; Awais Azam, M.; Naeem, U.; Amin, Y.; Loo, J.  Continuous authentication of smartphone users basedon activity pattern recognition using passive mobile sensing. Journal of Network and Computer Applications 2018, 109, 24 – 35. doi:https://doi.org/10.1016/j.jnca.2018.02.020.33
[3]Sánchez Sánchez, P.M.; Fernández Maimó, L.; Huertas Celdrán, A.; Martínez Pérez, G. AuthCODE: A privacy-preserving andmulti-device continuous authentication architecture based on machine and deep learning.Computers & Security, 2021, 103, 102168. doi:https://doi.org/10.1016/j.cose.2020.102168.
[4] Snyder, D.; Garcia-Romero, D.; Sell, G.; Povey, D.; Khudanpur, S. X-vectors: Robust DNN Embeddings for Speaker Recognition.2018 IEEE International Conference on Acoustics, Speech and Signal Processing (ICASSP). IEEE, 2018.
[5] Povey, D.; Ghoshal, A.; Boulianne, G.; Burget, L.; Glembek, O.; Goel, N.; Hannemann, M.; Motlicek, P.; Qian, Y.; Schwarz, P.;Silovsky, J.; Stemmer, G.; Vesely, K. The Kaldi Speech Recognition Toolkit.  IEEE 2011 Workshop on Automatic Speech Recognitionand Understanding. IEEE Signal Processing Society, 2011.  IEEE Catalog No.: CFP11SRW-USB.
[6] Povey, D. Models Kaldi.  https://kaldi-asr.org/models.html, 2021.  Accessed: 2021-04-07.
